<?php


require_once("../require.php");
$session=new Mysession("CONTINUE",false,false); 


try {
$dbh = new PDO(PDO_DNS,PDO_USER,PDO_PASS);
$sth = $dbh ->prepare("INSERT INTO rental (user_name , book_name , date) VALUES (:NAME , :TITLE , :DAY)");

$sth->bindValue(':NAME',$_SESSION['userid']);
$sth->bindValue(':TITLE',$_SESSION['book_name']);
$sth->bindValue(':DAY',$_SESSION['rental_day_db']);
$result = $sth -> execute();

}
catch (PDOexception $e) {
dump($e);
exit;
}



$smarty -> assign("day",$day);
$smarty -> assign("title","本の貸出"); //hederのtitle
$smarty -> assign("session_status",$session->getstatus());
$smarty -> display("borrow.tpl");


?>
